<?php

namespace StructType;

use \WsdlToPhp\PackageBase\AbstractStructBase;

/**
 * This class stands for InterlineALaCarteOfferType StructType
 * Meta information extracted from the WSDL
 * - documentation: A proposal to sell a specific set of products or Services under specific conditions, for a certain price. Can be the response to a shopping request. Can be a regular Offer or an A La Carte Offer. A La Carte Offer is defined as a
 * container for A La Carte Offer Items. This supports a shopping basket concept for non-flight services. The main purpose of this structure is to reduce the size of the messages by inserting Offer Items which are applicable to multiple flight-related
 * Offers. NB. For the OfferID of the ALaCarteOffer: Default OfferID identifier for A La Carte Offer Items in a scenario where items here are not selected for a flight-related Offer above. Business Identifier Fields: - [Shopping Response] Shopping
 * Response ID - Offer ID - [Carrier] Airline Designator Code
 * @subpackage Structs
 */
class InterlineALaCarteOfferType extends AbstractStructBase
{
    /**
     * The OfferID
     * Meta information extracted from the WSDL
     * - documentation: Carrier assigned ID which uniquely identifies a specific Offer across several messages. Offer ID facilitates the tracking and verification of individually priced offer(s) selected from the shopping response. Only the Offer IDs of the
     * ORA (Offer Responsible Airline) are returned in shopping responses. Offer ID is unique to each individually priced offer in the shopping response even if the offer price is zero. Offer ID may be specific to individual passengers in the offer, and may
     * be associated with a segment or a journey. The set of Offer IDs returned in a response are referenced by a Shopping Response ID. | An identifier is a character string used to uniquely identify one instance of an object within an identification scheme
     * that is managed by an agency.
     * - base: xs:token
     * - maxOccurs: 1
     * - minOccurs: 1
     * @var string
     */
    public $OfferID;
    /**
     * The OfferItem
     * Meta information extracted from the WSDL
     * - documentation: A priced grouping of one or more services within an Offer. The A La Carte Offer Item assigns a total price for all included services for all passengers and all segments referenced. Once constructed, the OfferItem cannot be modified.
     * - maxOccurs: unbounded
     * - minOccurs: 1
     * @var \StructType\ALaCarteOfferItemType[]
     */
    public $OfferItem;
    /**
     * The OwnerCode
     * Meta information extracted from the WSDL
     * - documentation: Airline code assigned to a carrier. Either ICAO-defined 3-character code or IATA-defined 2-character code. | The codelist contents of IATA Resolution 762 airline codes, or of ICAO airline codes. {codeListAgencyName}IATA or
     * ICAO{/codeListAgencyName} {codeListName}Resolution 762 Airline Codes or ICAO Airline Codes{/codeListName} | The codelist contents of IATA Resolution 762 airline codes, or of ICAO airline codes {codeListAgencyName}IATA or ICAO{/codeListAgencyName}
     * {codeListName}Resolution 762 Airline Codes or ICAO Airline Codes{/codeListName} | Either the IATA-defined 2-character code or the ICAO-defined 3-character code of an airline, as per the length of the value.
     * - base: AirlineDesigCodeContentType
     * - maxOccurs: 1
     * - minOccurs: 1
     * - pattern: ([A-Z]{3}|[A-Z]{2})|([0-9][A-Z])|([A-Z][0-9])
     * @var string
     */
    public $OwnerCode;
    /**
     * The BaggageDisclosureRefID
     * Meta information extracted from the WSDL
     * - documentation: Reference to a Bag Disclosure ID within this message. | An identifier is a character string used to uniquely identify one instance of an object within an identification scheme that is managed by an agency.
     * - base: xs:token
     * - maxOccurs: unbounded
     * - minOccurs: 0
     * @var string[]
     */
    public $BaggageDisclosureRefID;
    /**
     * The Commission
     * Meta information extracted from the WSDL
     * - documentation: An amount of money, typically a set percentage of the value involved, paid to an agent in a commercial transaction.
     * - maxOccurs: unbounded
     * - minOccurs: 0
     * @var \StructType\CommissionType[]
     */
    public $Commission;
    /**
     * The Desc
     * Meta information extracted from the WSDL
     * - documentation: An account or representation of the certain or major aspects, characteristics, or features of a person, object, or event.
     * - maxOccurs: unbounded
     * - minOccurs: 0
     * @var \StructType\DescType[]
     */
    public $Desc;
    /**
     * The DisclosureRefID
     * Meta information extracted from the WSDL
     * - documentation: Reference to a Disclosure ID within this message. | An identifier is a character string used to uniquely identify one instance of an object within an identification scheme that is managed by an agency.
     * - base: xs:token
     * - maxOccurs: 1
     * - minOccurs: 0
     * @var string
     */
    public $DisclosureRefID;
    /**
     * The MatchAppText
     * Meta information extracted from the WSDL
     * - documentation: Specifies which type of flight request the match information relate to (examples: Attribute, Affinity, Other). | Text is a character string such as a finite set of characters generally in the form of words of a language.
     * - base: xs:string
     * - maxOccurs: 1
     * - minOccurs: 0
     * @var string
     */
    public $MatchAppText;
    /**
     * The MatchPercent
     * Meta information extracted from the WSDL
     * - documentation: Offer match percentage to shopping criteria type. This information should be populated when there is a partial match of the initial shopping criteria. Example: 60 | A percent is a value representing a fraction of one
     * hundred,expressed as a quotient.
     * - base: xs:decimal
     * - maxOccurs: 1
     * - minOccurs: 0
     * @var float
     */
    public $MatchPercent;
    /**
     * The MatchTypeCode
     * Meta information extracted from the WSDL
     * - documentation: Offer match to shopping criteria type. Examples: Full, None, Partial, Other Note: An additional percentage qualifier, such as 50%, may be specified for a Partial match. | Data type for Offer Match Result ENUMs.
     * - base: MatchTypeCodeContentType
     * - maxOccurs: 1
     * - minOccurs: 0
     * @var string
     */
    public $MatchTypeCode;
    /**
     * The OfferExpirationTimeLimitDateTime
     * Meta information extracted from the WSDL
     * - documentation: The length of time an offer will persist in an airline's offer management system for use in subsequent transactions. Upon expiry, the expectation is that the offer is no longer retrievable and the shopping process must begin again.
     * Note the presence of an Offer Time Limit does not indicate either a guarantee of price or inventory against a given Offer item within the Offer. Should the offer time limit expire, any other time limit also expires unless an Order has been created or
     * changed. | A date time identifies a date and time of day to various common resolutions: year, month, week, day, hour, minute, second, and fraction of second.
     * - base: xs:dateTime
     * - maxOccurs: 1
     * - minOccurs: 0
     * @var string
     */
    public $OfferExpirationTimeLimitDateTime;
    /**
     * The PenaltyRefID
     * Meta information extracted from the WSDL
     * - documentation: Reference to a Penalty ID. | An identifier is a character string used to uniquely identify one instance of an object within an identification scheme that is managed by an agency.
     * - base: xs:token
     * - maxOccurs: unbounded
     * - minOccurs: 0
     * @var string[]
     */
    public $PenaltyRefID;
    /**
     * The RedemptionInd
     * Meta information extracted from the WSDL
     * - documentation: When TRUE, this Offer must be redeemed, e.g. it cannot be purchased. Note: Taxes may still apply. | An indicator is a list of two mutually exclusive Boolean values that express the only possible states of a property.
     * - base: xs:boolean
     * - maxOccurs: 1
     * - minOccurs: 0
     * @var bool
     */
    public $RedemptionInd;
    /**
     * The RequestedDateInd
     * Meta information extracted from the WSDL
     * - documentation: Indicator to specify if the offer relates to a requested date. For example in calendar search, this indicator will be set to 'true' if this airline offer is for a requested date and will not be present (or will be set to 'false' if
     * airline offer is for another date than requested one. | An indicator is a list of two mutually exclusive Boolean values that express the only possible states of a property.
     * - base: xs:boolean
     * - maxOccurs: 1
     * - minOccurs: 0
     * @var bool
     */
    public $RequestedDateInd;
    /**
     * The TotalPrice
     * Meta information extracted from the WSDL
     * - documentation: The amount of money expected, required, or given in payment for something.
     * - maxOccurs: 1
     * - minOccurs: 0
     * @var \StructType\PriceType
     */
    public $TotalPrice;
    /**
     * Constructor method for InterlineALaCarteOfferType
     * @uses InterlineALaCarteOfferType::setOfferID()
     * @uses InterlineALaCarteOfferType::setOfferItem()
     * @uses InterlineALaCarteOfferType::setOwnerCode()
     * @uses InterlineALaCarteOfferType::setBaggageDisclosureRefID()
     * @uses InterlineALaCarteOfferType::setCommission()
     * @uses InterlineALaCarteOfferType::setDesc()
     * @uses InterlineALaCarteOfferType::setDisclosureRefID()
     * @uses InterlineALaCarteOfferType::setMatchAppText()
     * @uses InterlineALaCarteOfferType::setMatchPercent()
     * @uses InterlineALaCarteOfferType::setMatchTypeCode()
     * @uses InterlineALaCarteOfferType::setOfferExpirationTimeLimitDateTime()
     * @uses InterlineALaCarteOfferType::setPenaltyRefID()
     * @uses InterlineALaCarteOfferType::setRedemptionInd()
     * @uses InterlineALaCarteOfferType::setRequestedDateInd()
     * @uses InterlineALaCarteOfferType::setTotalPrice()
     * @param string $offerID
     * @param \StructType\ALaCarteOfferItemType[] $offerItem
     * @param string $ownerCode
     * @param string[] $baggageDisclosureRefID
     * @param \StructType\CommissionType[] $commission
     * @param \StructType\DescType[] $desc
     * @param string $disclosureRefID
     * @param string $matchAppText
     * @param float $matchPercent
     * @param string $matchTypeCode
     * @param string $offerExpirationTimeLimitDateTime
     * @param string[] $penaltyRefID
     * @param bool $redemptionInd
     * @param bool $requestedDateInd
     * @param \StructType\PriceType $totalPrice
     */
    public function __construct($offerID = null, array $offerItem = array(), $ownerCode = null, array $baggageDisclosureRefID = array(), array $commission = array(), array $desc = array(), $disclosureRefID = null, $matchAppText = null, $matchPercent = null, $matchTypeCode = null, $offerExpirationTimeLimitDateTime = null, array $penaltyRefID = array(), $redemptionInd = null, $requestedDateInd = null, \StructType\PriceType $totalPrice = null)
    {
        $this
            ->setOfferID($offerID)
            ->setOfferItem($offerItem)
            ->setOwnerCode($ownerCode)
            ->setBaggageDisclosureRefID($baggageDisclosureRefID)
            ->setCommission($commission)
            ->setDesc($desc)
            ->setDisclosureRefID($disclosureRefID)
            ->setMatchAppText($matchAppText)
            ->setMatchPercent($matchPercent)
            ->setMatchTypeCode($matchTypeCode)
            ->setOfferExpirationTimeLimitDateTime($offerExpirationTimeLimitDateTime)
            ->setPenaltyRefID($penaltyRefID)
            ->setRedemptionInd($redemptionInd)
            ->setRequestedDateInd($requestedDateInd)
            ->setTotalPrice($totalPrice);
    }
    /**
     * Get OfferID value
     * @return string
     */
    public function getOfferID()
    {
        return $this->OfferID;
    }
    /**
     * Set OfferID value
     * @param string $offerID
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function setOfferID($offerID = null)
    {
        // validation for constraint: string
        if (!is_null($offerID) && !is_string($offerID)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($offerID, true), gettype($offerID)), __LINE__);
        }
        $this->OfferID = $offerID;
        return $this;
    }
    /**
     * Get OfferItem value
     * @return \StructType\ALaCarteOfferItemType[]
     */
    public function getOfferItem()
    {
        return $this->OfferItem;
    }
    /**
     * This method is responsible for validating the values passed to the setOfferItem method
     * This method is willingly generated in order to preserve the one-line inline validation within the setOfferItem method
     * @param array $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validateOfferItemForArrayConstraintsFromSetOfferItem(array $values = array())
    {
        $message = '';
        $invalidValues = [];
        foreach ($values as $interlineALaCarteOfferTypeOfferItemItem) {
            // validation for constraint: itemType
            if (!$interlineALaCarteOfferTypeOfferItemItem instanceof \StructType\ALaCarteOfferItemType) {
                $invalidValues[] = is_object($interlineALaCarteOfferTypeOfferItemItem) ? get_class($interlineALaCarteOfferTypeOfferItemItem) : sprintf('%s(%s)', gettype($interlineALaCarteOfferTypeOfferItemItem), var_export($interlineALaCarteOfferTypeOfferItemItem, true));
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('The OfferItem property can only contain items of type \StructType\ALaCarteOfferItemType, %s given', is_object($invalidValues) ? get_class($invalidValues) : (is_array($invalidValues) ? implode(', ', $invalidValues) : gettype($invalidValues)));
        }
        unset($invalidValues);
        return $message;
    }
    /**
     * Set OfferItem value
     * @throws \InvalidArgumentException
     * @param \StructType\ALaCarteOfferItemType[] $offerItem
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function setOfferItem(array $offerItem = array())
    {
        // validation for constraint: array
        if ('' !== ($offerItemArrayErrorMessage = self::validateOfferItemForArrayConstraintsFromSetOfferItem($offerItem))) {
            throw new \InvalidArgumentException($offerItemArrayErrorMessage, __LINE__);
        }
        $this->OfferItem = $offerItem;
        return $this;
    }
    /**
     * Add item to OfferItem value
     * @throws \InvalidArgumentException
     * @param \StructType\ALaCarteOfferItemType $item
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function addToOfferItem(\StructType\ALaCarteOfferItemType $item)
    {
        // validation for constraint: itemType
        if (!$item instanceof \StructType\ALaCarteOfferItemType) {
            throw new \InvalidArgumentException(sprintf('The OfferItem property can only contain items of type \StructType\ALaCarteOfferItemType, %s given', is_object($item) ? get_class($item) : (is_array($item) ? implode(', ', $item) : gettype($item))), __LINE__);
        }
        $this->OfferItem[] = $item;
        return $this;
    }
    /**
     * Get OwnerCode value
     * @return string
     */
    public function getOwnerCode()
    {
        return $this->OwnerCode;
    }
    /**
     * Set OwnerCode value
     * @param string $ownerCode
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function setOwnerCode($ownerCode = null)
    {
        // validation for constraint: string
        if (!is_null($ownerCode) && !is_string($ownerCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($ownerCode, true), gettype($ownerCode)), __LINE__);
        }
        // validation for constraint: pattern(([A-Z]{3}|[A-Z]{2})|([0-9][A-Z])|([A-Z][0-9]))
        if (!is_null($ownerCode) && !preg_match('/([A-Z]{3}|[A-Z]{2})|([0-9][A-Z])|([A-Z][0-9])/', $ownerCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a literal that is among the set of character sequences denoted by the regular expression ([A-Z]{3}|[A-Z]{2})|([0-9][A-Z])|([A-Z][0-9])', var_export($ownerCode, true)), __LINE__);
        }
        $this->OwnerCode = $ownerCode;
        return $this;
    }
    /**
     * Get BaggageDisclosureRefID value
     * @return string[]|null
     */
    public function getBaggageDisclosureRefID()
    {
        return $this->BaggageDisclosureRefID;
    }
    /**
     * This method is responsible for validating the values passed to the setBaggageDisclosureRefID method
     * This method is willingly generated in order to preserve the one-line inline validation within the setBaggageDisclosureRefID method
     * @param array $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validateBaggageDisclosureRefIDForArrayConstraintsFromSetBaggageDisclosureRefID(array $values = array())
    {
        $message = '';
        $invalidValues = [];
        foreach ($values as $interlineALaCarteOfferTypeBaggageDisclosureRefIDItem) {
            // validation for constraint: itemType
            if (!is_string($interlineALaCarteOfferTypeBaggageDisclosureRefIDItem)) {
                $invalidValues[] = is_object($interlineALaCarteOfferTypeBaggageDisclosureRefIDItem) ? get_class($interlineALaCarteOfferTypeBaggageDisclosureRefIDItem) : sprintf('%s(%s)', gettype($interlineALaCarteOfferTypeBaggageDisclosureRefIDItem), var_export($interlineALaCarteOfferTypeBaggageDisclosureRefIDItem, true));
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('The BaggageDisclosureRefID property can only contain items of type token, %s given', is_object($invalidValues) ? get_class($invalidValues) : (is_array($invalidValues) ? implode(', ', $invalidValues) : gettype($invalidValues)));
        }
        unset($invalidValues);
        return $message;
    }
    /**
     * Set BaggageDisclosureRefID value
     * @throws \InvalidArgumentException
     * @param string[] $baggageDisclosureRefID
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function setBaggageDisclosureRefID(array $baggageDisclosureRefID = array())
    {
        // validation for constraint: array
        if ('' !== ($baggageDisclosureRefIDArrayErrorMessage = self::validateBaggageDisclosureRefIDForArrayConstraintsFromSetBaggageDisclosureRefID($baggageDisclosureRefID))) {
            throw new \InvalidArgumentException($baggageDisclosureRefIDArrayErrorMessage, __LINE__);
        }
        $this->BaggageDisclosureRefID = $baggageDisclosureRefID;
        return $this;
    }
    /**
     * Add item to BaggageDisclosureRefID value
     * @throws \InvalidArgumentException
     * @param string $item
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function addToBaggageDisclosureRefID($item)
    {
        // validation for constraint: itemType
        if (!is_string($item)) {
            throw new \InvalidArgumentException(sprintf('The BaggageDisclosureRefID property can only contain items of type token, %s given', is_object($item) ? get_class($item) : (is_array($item) ? implode(', ', $item) : gettype($item))), __LINE__);
        }
        $this->BaggageDisclosureRefID[] = $item;
        return $this;
    }
    /**
     * Get Commission value
     * @return \StructType\CommissionType[]|null
     */
    public function getCommission()
    {
        return $this->Commission;
    }
    /**
     * This method is responsible for validating the values passed to the setCommission method
     * This method is willingly generated in order to preserve the one-line inline validation within the setCommission method
     * @param array $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validateCommissionForArrayConstraintsFromSetCommission(array $values = array())
    {
        $message = '';
        $invalidValues = [];
        foreach ($values as $interlineALaCarteOfferTypeCommissionItem) {
            // validation for constraint: itemType
            if (!$interlineALaCarteOfferTypeCommissionItem instanceof \StructType\CommissionType) {
                $invalidValues[] = is_object($interlineALaCarteOfferTypeCommissionItem) ? get_class($interlineALaCarteOfferTypeCommissionItem) : sprintf('%s(%s)', gettype($interlineALaCarteOfferTypeCommissionItem), var_export($interlineALaCarteOfferTypeCommissionItem, true));
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('The Commission property can only contain items of type \StructType\CommissionType, %s given', is_object($invalidValues) ? get_class($invalidValues) : (is_array($invalidValues) ? implode(', ', $invalidValues) : gettype($invalidValues)));
        }
        unset($invalidValues);
        return $message;
    }
    /**
     * Set Commission value
     * @throws \InvalidArgumentException
     * @param \StructType\CommissionType[] $commission
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function setCommission(array $commission = array())
    {
        // validation for constraint: array
        if ('' !== ($commissionArrayErrorMessage = self::validateCommissionForArrayConstraintsFromSetCommission($commission))) {
            throw new \InvalidArgumentException($commissionArrayErrorMessage, __LINE__);
        }
        $this->Commission = $commission;
        return $this;
    }
    /**
     * Add item to Commission value
     * @throws \InvalidArgumentException
     * @param \StructType\CommissionType $item
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function addToCommission(\StructType\CommissionType $item)
    {
        // validation for constraint: itemType
        if (!$item instanceof \StructType\CommissionType) {
            throw new \InvalidArgumentException(sprintf('The Commission property can only contain items of type \StructType\CommissionType, %s given', is_object($item) ? get_class($item) : (is_array($item) ? implode(', ', $item) : gettype($item))), __LINE__);
        }
        $this->Commission[] = $item;
        return $this;
    }
    /**
     * Get Desc value
     * @return \StructType\DescType[]|null
     */
    public function getDesc()
    {
        return $this->Desc;
    }
    /**
     * This method is responsible for validating the values passed to the setDesc method
     * This method is willingly generated in order to preserve the one-line inline validation within the setDesc method
     * @param array $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validateDescForArrayConstraintsFromSetDesc(array $values = array())
    {
        $message = '';
        $invalidValues = [];
        foreach ($values as $interlineALaCarteOfferTypeDescItem) {
            // validation for constraint: itemType
            if (!$interlineALaCarteOfferTypeDescItem instanceof \StructType\DescType) {
                $invalidValues[] = is_object($interlineALaCarteOfferTypeDescItem) ? get_class($interlineALaCarteOfferTypeDescItem) : sprintf('%s(%s)', gettype($interlineALaCarteOfferTypeDescItem), var_export($interlineALaCarteOfferTypeDescItem, true));
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('The Desc property can only contain items of type \StructType\DescType, %s given', is_object($invalidValues) ? get_class($invalidValues) : (is_array($invalidValues) ? implode(', ', $invalidValues) : gettype($invalidValues)));
        }
        unset($invalidValues);
        return $message;
    }
    /**
     * Set Desc value
     * @throws \InvalidArgumentException
     * @param \StructType\DescType[] $desc
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function setDesc(array $desc = array())
    {
        // validation for constraint: array
        if ('' !== ($descArrayErrorMessage = self::validateDescForArrayConstraintsFromSetDesc($desc))) {
            throw new \InvalidArgumentException($descArrayErrorMessage, __LINE__);
        }
        $this->Desc = $desc;
        return $this;
    }
    /**
     * Add item to Desc value
     * @throws \InvalidArgumentException
     * @param \StructType\DescType $item
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function addToDesc(\StructType\DescType $item)
    {
        // validation for constraint: itemType
        if (!$item instanceof \StructType\DescType) {
            throw new \InvalidArgumentException(sprintf('The Desc property can only contain items of type \StructType\DescType, %s given', is_object($item) ? get_class($item) : (is_array($item) ? implode(', ', $item) : gettype($item))), __LINE__);
        }
        $this->Desc[] = $item;
        return $this;
    }
    /**
     * Get DisclosureRefID value
     * @return string|null
     */
    public function getDisclosureRefID()
    {
        return $this->DisclosureRefID;
    }
    /**
     * Set DisclosureRefID value
     * @param string $disclosureRefID
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function setDisclosureRefID($disclosureRefID = null)
    {
        // validation for constraint: string
        if (!is_null($disclosureRefID) && !is_string($disclosureRefID)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($disclosureRefID, true), gettype($disclosureRefID)), __LINE__);
        }
        $this->DisclosureRefID = $disclosureRefID;
        return $this;
    }
    /**
     * Get MatchAppText value
     * @return string|null
     */
    public function getMatchAppText()
    {
        return $this->MatchAppText;
    }
    /**
     * Set MatchAppText value
     * @param string $matchAppText
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function setMatchAppText($matchAppText = null)
    {
        // validation for constraint: string
        if (!is_null($matchAppText) && !is_string($matchAppText)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($matchAppText, true), gettype($matchAppText)), __LINE__);
        }
        $this->MatchAppText = $matchAppText;
        return $this;
    }
    /**
     * Get MatchPercent value
     * @return float|null
     */
    public function getMatchPercent()
    {
        return $this->MatchPercent;
    }
    /**
     * Set MatchPercent value
     * @param float $matchPercent
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function setMatchPercent($matchPercent = null)
    {
        // validation for constraint: float
        if (!is_null($matchPercent) && !(is_float($matchPercent) || is_numeric($matchPercent))) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a float value, %s given', var_export($matchPercent, true), gettype($matchPercent)), __LINE__);
        }
        $this->MatchPercent = $matchPercent;
        return $this;
    }
    /**
     * Get MatchTypeCode value
     * @return string|null
     */
    public function getMatchTypeCode()
    {
        return $this->MatchTypeCode;
    }
    /**
     * Set MatchTypeCode value
     * @param string $matchTypeCode
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function setMatchTypeCode($matchTypeCode = null)
    {
        // validation for constraint: string
        if (!is_null($matchTypeCode) && !is_string($matchTypeCode)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($matchTypeCode, true), gettype($matchTypeCode)), __LINE__);
        }
        $this->MatchTypeCode = $matchTypeCode;
        return $this;
    }
    /**
     * Get OfferExpirationTimeLimitDateTime value
     * @return string|null
     */
    public function getOfferExpirationTimeLimitDateTime()
    {
        return $this->OfferExpirationTimeLimitDateTime;
    }
    /**
     * Set OfferExpirationTimeLimitDateTime value
     * @param string $offerExpirationTimeLimitDateTime
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function setOfferExpirationTimeLimitDateTime($offerExpirationTimeLimitDateTime = null)
    {
        // validation for constraint: string
        if (!is_null($offerExpirationTimeLimitDateTime) && !is_string($offerExpirationTimeLimitDateTime)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a string, %s given', var_export($offerExpirationTimeLimitDateTime, true), gettype($offerExpirationTimeLimitDateTime)), __LINE__);
        }
        $this->OfferExpirationTimeLimitDateTime = $offerExpirationTimeLimitDateTime;
        return $this;
    }
    /**
     * Get PenaltyRefID value
     * @return string[]|null
     */
    public function getPenaltyRefID()
    {
        return $this->PenaltyRefID;
    }
    /**
     * This method is responsible for validating the values passed to the setPenaltyRefID method
     * This method is willingly generated in order to preserve the one-line inline validation within the setPenaltyRefID method
     * @param array $values
     * @return string A non-empty message if the values does not match the validation rules
     */
    public static function validatePenaltyRefIDForArrayConstraintsFromSetPenaltyRefID(array $values = array())
    {
        $message = '';
        $invalidValues = [];
        foreach ($values as $interlineALaCarteOfferTypePenaltyRefIDItem) {
            // validation for constraint: itemType
            if (!is_string($interlineALaCarteOfferTypePenaltyRefIDItem)) {
                $invalidValues[] = is_object($interlineALaCarteOfferTypePenaltyRefIDItem) ? get_class($interlineALaCarteOfferTypePenaltyRefIDItem) : sprintf('%s(%s)', gettype($interlineALaCarteOfferTypePenaltyRefIDItem), var_export($interlineALaCarteOfferTypePenaltyRefIDItem, true));
            }
        }
        if (!empty($invalidValues)) {
            $message = sprintf('The PenaltyRefID property can only contain items of type token, %s given', is_object($invalidValues) ? get_class($invalidValues) : (is_array($invalidValues) ? implode(', ', $invalidValues) : gettype($invalidValues)));
        }
        unset($invalidValues);
        return $message;
    }
    /**
     * Set PenaltyRefID value
     * @throws \InvalidArgumentException
     * @param string[] $penaltyRefID
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function setPenaltyRefID(array $penaltyRefID = array())
    {
        // validation for constraint: array
        if ('' !== ($penaltyRefIDArrayErrorMessage = self::validatePenaltyRefIDForArrayConstraintsFromSetPenaltyRefID($penaltyRefID))) {
            throw new \InvalidArgumentException($penaltyRefIDArrayErrorMessage, __LINE__);
        }
        $this->PenaltyRefID = $penaltyRefID;
        return $this;
    }
    /**
     * Add item to PenaltyRefID value
     * @throws \InvalidArgumentException
     * @param string $item
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function addToPenaltyRefID($item)
    {
        // validation for constraint: itemType
        if (!is_string($item)) {
            throw new \InvalidArgumentException(sprintf('The PenaltyRefID property can only contain items of type token, %s given', is_object($item) ? get_class($item) : (is_array($item) ? implode(', ', $item) : gettype($item))), __LINE__);
        }
        $this->PenaltyRefID[] = $item;
        return $this;
    }
    /**
     * Get RedemptionInd value
     * @return bool|null
     */
    public function getRedemptionInd()
    {
        return $this->RedemptionInd;
    }
    /**
     * Set RedemptionInd value
     * @param bool $redemptionInd
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function setRedemptionInd($redemptionInd = null)
    {
        // validation for constraint: boolean
        if (!is_null($redemptionInd) && !is_bool($redemptionInd)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a bool, %s given', var_export($redemptionInd, true), gettype($redemptionInd)), __LINE__);
        }
        $this->RedemptionInd = $redemptionInd;
        return $this;
    }
    /**
     * Get RequestedDateInd value
     * @return bool|null
     */
    public function getRequestedDateInd()
    {
        return $this->RequestedDateInd;
    }
    /**
     * Set RequestedDateInd value
     * @param bool $requestedDateInd
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function setRequestedDateInd($requestedDateInd = null)
    {
        // validation for constraint: boolean
        if (!is_null($requestedDateInd) && !is_bool($requestedDateInd)) {
            throw new \InvalidArgumentException(sprintf('Invalid value %s, please provide a bool, %s given', var_export($requestedDateInd, true), gettype($requestedDateInd)), __LINE__);
        }
        $this->RequestedDateInd = $requestedDateInd;
        return $this;
    }
    /**
     * Get TotalPrice value
     * @return \StructType\PriceType|null
     */
    public function getTotalPrice()
    {
        return $this->TotalPrice;
    }
    /**
     * Set TotalPrice value
     * @param \StructType\PriceType $totalPrice
     * @return \StructType\InterlineALaCarteOfferType
     */
    public function setTotalPrice(\StructType\PriceType $totalPrice = null)
    {
        $this->TotalPrice = $totalPrice;
        return $this;
    }
}
